==> plexus-archiver_4.2.7.orig.tar.xz: plexus-archiver-plexus-archiver-4.2.7/README.md <==
Plexus-archiver
===============

[![Apache License, Version 2.0, January 2004](https://img.shields.io/github/license/codehaus-plexus/plexus-archiver.svg?label=License)](http://www.apache.org/licenses/)
[![Maven Central](https://img.shields.io/maven-central/v/org.codehaus.plexus/plexus-archiver.svg?label=Maven%20Central)](https://search.maven.org/artifact/org.codehaus.plexus/plexus-archiver)
[![Build Status](https://travis-ci.org/codehaus-plexus/plexus-archiver.svg?branch=master)](https://travis-ci.org/codehaus-plexus/plexus-archiver)
[![Reproducible Builds](https://img.shields.io/badge/Reproducible_Builds-ok-green?labelColor=blue)](https://github.com/jvm-repo-rebuild/reproducible-central#org.codehaus.plexus:plexus-archiver)

The current master is now at https://github.com/codehaus-plexus/plexus-archiver

## Important Hint

Based on a hint of snyk.io security team they have found a possible security issue. 
Furthermore they have offered an patch to prevent the possible security issue. 
This patch has been integrated into the Release 3.6.0

## Release Notes

You can find details about the different releases in the [Release Notes](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md).

 * [Release 4.2.5](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.5).
 * [Release 4.2.4](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.4).
 * [Release 4.2.3](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.3).
 * [Release 4.2.2](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.2).
 * [Release 4.2.1](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-421).
 * [Release 4.2.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-420).
 * [Release 4.1.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-410).
 * [Release 4.0.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-400).

==> plexus-archiver_4.6.1.orig.tar.xz: plexus-archiver-plexus-archiver-4.6.1/README.md <==
Plexus-archiver
===============

[![Apache License, Version 2.0, January 2004](https://img.shields.io/github/license/codehaus-plexus/plexus-archiver.svg?label=License)](http://www.apache.org/licenses/)
[![Maven Central](https://img.shields.io/maven-central/v/org.codehaus.plexus/plexus-archiver.svg?label=Maven%20Central)](https://search.maven.org/artifact/org.codehaus.plexus/plexus-archiver)
[![GitHub CI](https://github.com/codehaus-plexus/plexus-archiver/actions/workflows/maven.yml/badge.svg)](https://github.com/codehaus-plexus/plexus-archiver/actions/workflows/maven.yml)
[![Reproducible Builds](https://img.shields.io/badge/Reproducible_Builds-ok-green?labelColor=blue)](https://github.com/jvm-repo-rebuild/reproducible-central#org.codehaus.plexus:plexus-archiver)

The current master is now at https://github.com/codehaus-plexus/plexus-archiver

## Important Hint

Based on a hint of snyk.io security team they have found a possible security issue. 
Furthermore they have offered an patch to prevent the possible security issue. 
This patch has been integrated into the Release 3.6.0

## Release Notes

You can find details about the different releases in the [Release Notes](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md).

 * [Release 4.2.5](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.5).
 * [Release 4.2.4](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.4).
 * [Release 4.2.3](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.3).
 * [Release 4.2.2](https://github.com/codehaus-plexus/plexus-archiver/releases/tag/plexus-archiver-4.2.2).
 * [Release 4.2.1](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-421).
 * [Release 4.2.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-420).
 * [Release 4.1.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-410).
 * [Release 4.0.0](https://github.com/codehaus-plexus/plexus-archiver/blob/master/ReleaseNotes.md#plexus-archiver-400).
